<?php
/*
All source code copyright and proprietary Melonfire, 2001 and 2002. All content, brand names and trademarks copyright and proprietary Melonfire, 2001 and 2002. All rights reserved. Copyright infringement is a violation of law.

This source code is provided with NO WARRANTY WHATSOEVER. It is produced and meant for illustrative purposes only, and is NOT recommended for use in production environments. 

Read more articles like this one at http://www.melonfire.com/community/columns/trog/ and http://www.melonfire.com/
*/

// errorReporter.class.php
// class to capture and display errors in a consistent manner

class errorReporter
{

	//
	// private variables
	//
	var $_errors = array();

	// define main error types (add to this list as per your requirements)
	// < 1000 are fatal (script stops immediately)
	// > 1000 are non-fatal (script stops once all non-fatals have been processed)
	var $_errorTypes = array(
	100 => "Database error",
	200 => "File I/O error",
	300 => "Authentication error",
	400 => "Script error",

	1100 => "Form error",
	1200 => "URL error"
	);

	// error subtypes
	// linked to above via primary type
	var $_errorsubTypes = array(
	101 => "Error in SQL query",
	102 => "Could not connect to database server",
	103 => "Database already exists",
	104 => "Could not select database",
	
	201 => "Could not create directory",
	202 => "Could not copy file(s)",
	203 => "Could not execute command",
	204 => "Could not read configuration file",
	205 => "Could not delete file(s)",
	206 => "Could not read file(s)",
	207 => "Could not write file(s)",
	208 => "Could not open file(s)",
	209 => "File already exists",
	210 => "Could not delete directory",

	301 => "Session expired",

	401 => "An internal script error occurred",

	1101 => "Required field empty",
	1102 => "Invalid data in field",
	1103 => "File upload unsuccessful",

	1201 => "Missing record identifier(s)"
	);

	//
	// public methods
	//

	// constructor
	function errorReporter()
	{

		// initialize error stack
		$this->flushErrors();

		// start output buffering
		ob_start();
	}

	// get number of errors in stack
	function numErrors()
	{
		return sizeof($this->_errors);
	}

	// manually raise an exception
	function raiseError($subtype=NULL, $data="No additional information available")
	{
		$this->_errors[] = array("subtype" => $subtype, "data" => $data);

		if ($this->_getErrorType($subtype) < 1000)
		{
			// fatal
			$this->displayFatalError($subtype, $data);
		}

		return $this->_errors;
	}

	// clean stack
	function flushErrors()
	{
		$this->_errors = array();
		return $this->_errors;
	}

	// fatal error handler
	// clear previously-drawn screen
	// display error template with message
	// stop script processing and die()
	function displayFatalError($subtype, $data)
	{
		ob_clean();
		$errorType = $this->_errorTypes[$this->_getErrorType($subtype)];
		$errorCode = $subtype;
		$errorMsg = $this->_errorsubTypes[$subtype];
		$addInfo = $data;
		include("error-fatal.php");
		die;
	}

	// non-fatal error handler
	// clear previously-drawn screen
	// build an array of non-fatal errors 
	// and then die()
	function displayNonFatalErrors()
	{
		ob_clean();

		$errorList = array();		
		for($x=0; $x<$this->numErrors(); $x++)
		{
			$errorType = $this->_errorTypes[$this->_getErrorType($this->_errors[$x]["subtype"])];
			$errorCode = $this->_errors[$x]["subtype"];
			$errorMsg = $this->_errorsubTypes[$this->_errors[$x]["subtype"]];
			$addInfo = $this->_errors[$x]["data"];
			$errorList[] = array($errorType, $errorCode, $errorMsg, $addInfo);
		}
		include("error-non-fatal.php");
		die;
	}


	//
	// private methods
	//
	
	// internal function to map subtype to primary type
	function _getErrorType($subtype)
	{
		return floor($subtype/10)*10;
	}
	
}

?>